@@ -2,18 +2,15 @@
 #
 # This software is released under the MIT License.
 # https://opensource.org/licenses/MIT
-import weakref
 import json
 import time
 import tempfile
 import math
-from dask_jobqueue import HTCondorCluster
 from dask_jobqueue.htcondor import HTCondorJob
 from subprocess import check_output, STDOUT
 from jinja2 import Environment, PackageLoader, select_autoescape
 
-from distributed.deploy.spec import ProcessInterface, SpecCluster
-from dask_jobqueue.core import Job
+from distributed.deploy.spec import ProcessInterface, SpecCluster, NoOpAwaitable
 
 
 class Process(ProcessInterface):
@@ -78,7 +75,7 @@ class Scheduler(Process):
         super().__init__()
 
     def scale(self, n=0, memory=None, cores=None):
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def adapt(
         self,
@@ -91,7 +88,7 @@ class Scheduler(Process):
         maximum_memory: str = None,
         **kwargs,
     ):
-        raise NotImplementedError
+        raise NotImplementedError()
 
     async def start(self):
 
@@ -193,7 +190,13 @@ class RemoteHTCondor(SpecCluster):
         )
 
     def scale(self, n=0, memory=None, cores=None):
-        self.scheduler.scale(n=n, memory=memory, cores=cores)
+        try:
+            self.scheduler.scale(n=n, memory=memory, cores=cores)
+        except Exception as ex:
+            raise ex
+
+        if self.asynchronous:
+            return NoOpAwaitable()
 
     def adapt(
         self,
@@ -206,30 +209,22 @@ class RemoteHTCondor(SpecCluster):
         maximum_memory: str = None,
         **kwargs,
     ):
-        self.scheduler.adapt(
-            *args,
-            minimum=minimum,
-            maximum=maximum,
-            minimum_cores=minimum_cores,
-            maximum_cores=maximum_cores,
-            minimum_memory=minimum_memory,
-            maximum_memory=maximum_memory,
-            **kwargs,
-        )
-        raise NotImplementedError
+        try:
+            self.scheduler.adapt(
+                *args,
+                minimum=minimum,
+                maximum=maximum,
+                minimum_cores=minimum_cores,
+                maximum_cores=maximum_cores,
+                minimum_memory=minimum_memory,
+                maximum_memory=maximum_memory,
+                **kwargs,
+            )
+        except Exception as ex:
+            raise ex
 
 
 def CreateRemoteHTCondor():
-    # workers = {
-    #     0:{
-    #         "cls": Job,
-    #         "options": {
-    #             "cores": 1,
-    #             "memory": "3GB",
-    #             "disk": "1GB"
-    #         }
-    #     }
-    #     }
     sched = {"cls": Scheduler, "options": {}}  # Use local scheduler for now
 
     return SpecCluster({}, sched, name="SSHCluster")
